@@ -1,12 +1,12 @@
 package JSONAPI::Document::Builder;
-$JSONAPI::Document::Builder::VERSION = '2.1';
+$JSONAPI::Document::Builder::VERSION = '2.2';
 =head1 NAME
 
 JSONAPI::Document::Builder - Resource Document builder
 
 =head1 VERSION
 
-version 2.1
+version 2.2
 
 =head1 DESCRIPTION
 
@@ -35,7 +35,7 @@ Main caller method; Builds the resource document for C<row>.
 sub build {
     my ($self) = @_;
     my $row    = $self->row;
-    my $type   = lc($row->result_source->source_name());
+    my $type   = $row->result_source->source_name();
 
     my %document = (
         id         => $row->id(),
@@ -56,8 +56,6 @@ sub build_relationship {
     $options //= {};
     my $builder = JSONAPI::Document::Builder::Relationships->new(
         api_url          => $self->api_url,
-        chi              => $self->chi,
-        segmenter        => $self->segmenter,
         fields           => $fields,
         kebab_case_attrs => $self->kebab_case_attrs,
         row              => $self->row,
